Proximate analysis bases
========================

Proximate analysis provides the percentage composition of a material in terms of fixed carbon (FC), volatile matter (VM), ash, and moisture. It can be represented on an as-determined (ad), as-received basis (ar), dry basis (d), and dry-ash free basis (daf).

Source code
-----------

.. autoclass:: chemics.Proximate
   :members:
